DOuze
=====

A DigitalOcean client library aimed to be a backend for Ansible modules.

You can find:

- `douze.api.DoApi` &mdash; The main API which mimics the REST API
- `douze.api.DoIdemApi` &mdash; The idempotent API which can power Ansible
  modules
